"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createImportsTransformer = void 0;
var typescript_1 = require("typescript");
var get_url_for_file_1 = require("./utils/get-url-for-file");
/**
 * Create source code transformer
 * @internal
 * @param cwd - working dir
 * @param resolve - dependencies resolver
 * @param file - target file
 * @param preloadList - list modules to preload
 */
function createImportsTransformer(cwd, resolve, file, preloadList) {
    /**
     * Creates import url.
     * @param target - for the dependency
     */
    var url = function (target) {
        var url;
        var resolution = resolve(file, target);
        if (resolution.isExternal) {
            url = resolution.resolution;
        }
        else if (resolution.isUrl) {
            url = resolution.resolution;
        }
        else {
            url = (0, get_url_for_file_1.getUrlForFile)(cwd, resolution.resolution);
        }
        if (preloadList.indexOf(url) < 0) {
            preloadList.push(url);
        }
        return url;
    };
    return function (context) {
        // creates visitor
        var visitor = function (node) {
            var _a;
            // dynamic import call
            if ((0, typescript_1.isCallExpression)(node) && node.expression.kind === typescript_1.SyntaxKind.ImportKeyword) {
                var arg = node.arguments[0];
                if ((0, typescript_1.isStringLiteral)(arg)) {
                    return context.factory.updateCallExpression(node, node.expression, node.typeArguments, [
                        context.factory.createStringLiteral(url(arg.text))
                    ]);
                }
                // todo report problematic import
            }
            // export ... from ...
            if ((0, typescript_1.isExportDeclaration)(node) && !node.isTypeOnly) {
                var moduleSpecifier = node.moduleSpecifier;
                if (moduleSpecifier && (0, typescript_1.isStringLiteral)(moduleSpecifier)) {
                    return context.factory.updateExportDeclaration(node, node.decorators, node.modifiers, node.isTypeOnly, node.exportClause, context.factory.createStringLiteral(url(moduleSpecifier.text)));
                }
            }
            // import ... from ...
            if ((0, typescript_1.isImportDeclaration)(node) && !((_a = node.importClause) === null || _a === void 0 ? void 0 : _a.isTypeOnly)) {
                var moduleSpecifier = node.moduleSpecifier;
                if ((0, typescript_1.isStringLiteral)(moduleSpecifier)) {
                    return context.factory.updateImportDeclaration(node, node.decorators, node.modifiers, node.importClause, context.factory.createStringLiteral(url(moduleSpecifier.text)));
                }
                return node;
            }
            return (0, typescript_1.visitEachChild)(node, visitor, context);
        };
        return function (node) {
            return (0, typescript_1.visitEachChild)(node, visitor, context);
        };
    };
}
exports.createImportsTransformer = createImportsTransformer;
//# sourceMappingURL=create-imports-transformer.js.map