"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLogger = exports.diagnosticToString = exports.loggerPrefix = exports.LogLevel = void 0;
var tslib_1 = require("tslib");
var typescript_1 = require("typescript");
/**
 * @public
 */
exports.LogLevel = {
    void: 1,
    error: 2,
    warn: 3,
    info: 4,
    debug: 5,
};
/**
 * @internal
 */
exports.loggerPrefix = 'express-typescript-compile:';
/**
 * @internal
 */
var diagnosticToString = function (diagnostics, cwd) {
    return (0, typescript_1.formatDiagnostics)(diagnostics, {
        getCanonicalFileName: function (fileName) { return fileName; },
        getCurrentDirectory: function () { return cwd; },
        getNewLine: function () { return '\n'; }
    });
};
exports.diagnosticToString = diagnosticToString;
/**
 * @internal
 * @param level - logging level
 * @param baseLogger - base logger
 */
var createLogger = function (level, baseLogger) {
    if (level === void 0) { level = exports.LogLevel.warn; }
    if (baseLogger === void 0) { baseLogger = console; }
    return ['debug', 'info', 'warn', 'error'].reduce(function (logger, key) {
        var _a;
        return ((0, tslib_1.__assign)((0, tslib_1.__assign)({}, logger), (_a = {}, _a[key] = function () {
            var data = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                data[_i] = arguments[_i];
            }
            if (level > (exports.LogLevel[key] - 1)) {
                baseLogger[key].apply(baseLogger, (0, tslib_1.__spreadArray)([exports.loggerPrefix], data, false));
            }
        }, _a)));
    }, {});
};
exports.createLogger = createLogger;
//# sourceMappingURL=logger.js.map