"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.modulesImportHandler = void 0;
var tslib_1 = require("tslib");
var path_1 = require("path");
var get_url_for_file_1 = require("./utils/get-url-for-file");
/**
 * Request handler which is responsible for serving es6 module source code.
 * @internal
 * @param config - configuration
 * @param sourceProvider - source provider
 * @param logger - logger
 */
var modulesImportHandler = function (config, sourceProvider, logger) {
    var extensions = config.resolve.extensions;
    return function (req, res, next) { return (0, tslib_1.__awaiter)(void 0, void 0, void 0, function () {
        var source, importQuery, importContextQuery, path, originalUrl, moduleImport, ext, e_1;
        return (0, tslib_1.__generator)(this, function (_a) {
            switch (_a.label) {
                case 0:
                    importQuery = req.query[get_url_for_file_1.importQueryParam];
                    importContextQuery = req.query[get_url_for_file_1.importContextQueryParam];
                    req.moduleImport = !!importQuery;
                    req.moduleImportContext = typeof importContextQuery === 'string'
                        ? importContextQuery
                        : undefined;
                    path = req.path, originalUrl = req.originalUrl, moduleImport = req.moduleImport;
                    ext = (0, path_1.extname)(path);
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 6, , 7]);
                    if (!(moduleImport && (!extensions || extensions.indexOf(ext) > -1))) return [3 /*break*/, 3];
                    logger.debug("handling " + originalUrl + " by moduleImport/extension match");
                    return [4 /*yield*/, sourceProvider("" + (req.moduleImportContext || '') + path)];
                case 2:
                    source = _a.sent();
                    return [3 /*break*/, 5];
                case 3:
                    if (!(path.endsWith('.ts') || path.endsWith('.tsx'))) return [3 /*break*/, 5];
                    logger.debug("handling " + originalUrl + " by direct ts/tsx import match");
                    return [4 /*yield*/, sourceProvider(path)];
                case 4:
                    source = _a.sent();
                    _a.label = 5;
                case 5:
                    if (source) {
                        res.contentType('application/javascript');
                        res.send(source);
                    }
                    else {
                        next();
                    }
                    return [3 /*break*/, 7];
                case 6:
                    e_1 = _a.sent();
                    logger.error("problem with transpile a requested module " + originalUrl, e_1);
                    res.statusCode = 500;
                    res.send("Problem with transpile a requested module " + originalUrl + ": " + e_1.message);
                    return [3 /*break*/, 7];
                case 7: return [2 /*return*/];
            }
        });
    }); };
};
exports.modulesImportHandler = modulesImportHandler;
//# sourceMappingURL=modules-import-handler.js.map